;;; ada-ref-man.el --- Ada Reference Manual 2012
;;
;;; Copyright (C) 2014, 2017, 2019, 2020  Free Software Foundation, Inc.
;;
;; Author: Stephen Leake <stephen_leake@member.fsf.org>
;; Maintainer: Stephen Leake <stephen_leake@member.fsf.org>
;; Keywords: languages
;;  ada
;; Package-Type: multi
;; Version: 2020.1
;; url: http://stephe-leake.org/ada/arm.html

;;; ada-ref-man.el ends here
