;; Generated package description from ada-ref-man.el  -*- no-byte-compile: t -*-
(define-package "ada-ref-man" "2020.1" "Ada Reference Manual 2012" 'nil :commit "b86a173c1488989fd06f0b612e7b7acee9fda070" :authors '(("Stephen Leake" . "stephen_leake@member.fsf.org")) :maintainer '("Stephen Leake" . "stephen_leake@member.fsf.org") :keywords '("languages" "ada") :url "http://stephe-leake.org/ada/arm.html")
